import common from 'oci-common'
import { ConfigFileAuthenticationDetailsProvider, core } from 'oci-sdk'
import { InstanceActionRequest } from 'oci-core/lib/request/instance-action-request'
import Helper from '../utils/Helper'
import Logger from '../utils/Logger'
import * as process from 'process'

export default class OciConnector {
  private readonly provider: common.ConfigFileAuthenticationDetailsProvider
  private computeClient: core.ComputeClient

  constructor() {
    const configFilePath = process.env.OCI_CONFIG_PATH
    this.provider = new ConfigFileAuthenticationDetailsProvider(configFilePath)
    this.computeClient = new core.ComputeClient({
      authenticationDetailsProvider: this.provider,
    })
  }

  async getInstanceState(instanceId: string) {
    const getState = await this.computeClient.getInstance({
      instanceId: instanceId,
    })

    return getState.instance.lifecycleState
  }

  async startInstance(instanceId: string) {
    const startTask = await this.computeClient.instanceAction({
      instanceId: instanceId,
      action: InstanceActionRequest.Action.Start,
    })

    Logger.info(`Starting instance '${startTask.instance.displayName}' ...`)

    let isStarted = false

    while (!isStarted) {
      const instanceState = await this.getInstanceState(instanceId)

      if (instanceState === core.models.Instance.LifecycleState.Running) {
        isStarted = true
      }

      await Helper.sleep(1000)
    }

    Logger.info(`Instance '${startTask.instance.displayName}' started.`)
  }

  async stopInstance(instanceId: string) {
    const stopTask = await this.computeClient.instanceAction({
      instanceId: instanceId,
      action: InstanceActionRequest.Action.Softstop,
    })

    Logger.info(`Stopping instance '${stopTask.instance.displayName}' ...`)

    let isStopped = false

    while (!isStopped) {
      const instanceState = await this.getInstanceState(instanceId)

      if (instanceState === core.models.Instance.LifecycleState.Stopped) {
        isStopped = true
      }

      await Helper.sleep(1000)
    }

    Logger.info(`Instance '${stopTask.instance.displayName}' stopped.`)
  }
}
