import * as dotenv from 'dotenv'
import OciConnector from './connectors/Oci.Connector'
import VBRConnector from './connectors/VBR.Connector'
import * as process from 'process'

import * as cron from 'node-cron'
import Logger from './utils/Logger'
import * as moment from 'moment'

dotenv.config()

async function main() {
  const instanceId = process.env.INSTANCE_ID
  const ociConnector = new OciConnector()
  const vbrConnector = new VBRConnector()

  cron.schedule(
    '45 1 * * *',
    async () => {
      await ociConnector.startInstance(instanceId)
      await vbrConnector.ensureManagerRunning()
    },
    {
      scheduled: true,
      timezone: 'Asia/Jakarta',
    },
  )

  cron.schedule(
    '0 2 * * *',
    async () => {
      const dateNow = moment()

      console.log(dateNow)
      await vbrConnector.ensureAllBackupJobDone(dateNow)
      await ociConnector.stopInstance(instanceId)
    },
    {
      scheduled: true,
      timezone: 'Asia/Jakarta',
    },
  )

  Logger.info('Cron is installed.')
}

main().catch((error) => {
  console.log(error)
})
